# FlexSEA


`flexsea` is a Python package for interacting with Dephy's wearable robotic devices.
It can be used for gathering data from a device or for writing your own controller.

## Installation

Please see the installation documentation [here](./docs/install.md) for detailed
installation instructions.


## Usage

### Demos

A good reference for what `flexsea` is capable of is the collection of demo scripts
that live in the `demos/` directory. The demos are numbered and should be viewed in
order, as each successive demo builds off of the information presented in the previous
one. Each demo has verbose comments explaining each step.

You can also find a quickstart guide [here](./docs/quickstart.md)


### API Overview

Please see the api documentation [here](./docs/api.md).


## Contributing

If you find a bug or have a feature request, please fork the repository, make your
changes, and then issue a pull request (PR). We'd love to hear from you!
